@@ -24,11 +24,11 @@ import sys
 from jinja2 import contextfilter
 from jinja2 import contextfunction
 from jinja2 import Environment
-from jinja2 import FileSystemLoader
 import pymod2pkg
 
 import yaml
 
+from renderspec.distloader import RenderspecLoader
 from renderspec import versions
 
 
@@ -147,21 +147,35 @@ def _env_register_filters_and_globals(env):
 
 def generate_spec(spec_style, epochs, requirements, input_template_path):
     """generate a spec file with the given style and the given template"""
-    env = Environment(loader=FileSystemLoader(
-        os.path.dirname(input_template_path)))
+
+    env = Environment(loader=RenderspecLoader(
+        template_fn=input_template_path),
+        trim_blocks=True)
 
     _env_register_filters_and_globals(env)
 
-    template = env.get_template(os.path.basename(input_template_path))
+    template_name = '.spec'
+    if spec_style in env.loader.list_templates():
+        template_name = spec_style
+    template = env.get_template(template_name)
     return template.render(spec_style=spec_style, epochs=epochs,
                            requirements=requirements)
 
 
+def _is_fedora(distname):
+    """detect Fedora-based distro (e.g Fedora, CentOS, RHEL)"""
+    distname = distname.lower()
+    for x in ["fedora", "centos", "red hat"]:
+        if x in distname:
+            return True
+    return False
+
+
 def _get_default_distro():
     distname, version, id_ = platform.linux_distribution()
     if "suse" in distname.lower():
         return "suse"
-    elif "fedora" in distname.lower():
+    elif _is_fedora(distname):
         return "fedora"
     else:
         return "unknown"
@@ -183,20 +197,20 @@ def _get_default_template():
 
 def _get_epochs(filename):
     """get a dictionary with pkg-name->epoch mapping"""
-    if os.path.exists(filename):
+    epochs = {}
+    if filename is not None:
         with open(filename, 'r') as f:
             data = yaml.safe_load(f.read())
-            return dict(data['epochs'])
-    return {}
+            epochs.update(data['epochs'])
+    return epochs
 
 
 def _get_requirements(filenames):
     """get a dictionary with pkg-name->min-version mapping"""
     reqs = {}
     for filename in filenames:
-        if os.path.exists(filename):
-            with open(filename, 'r') as f:
-                reqs.update(versions.get_requirements(f.readlines()))
+        with open(filename, 'r') as f:
+            reqs.update(versions.get_requirements(f.readlines()))
     return reqs
 
 
@@ -210,9 +224,7 @@ def process_args():
     parser.add_argument("--spec-style", help="distro style you want to use. "
                         "default: %s" % (distro), default=distro,
                         choices=['suse', 'fedora'])
-    parser.add_argument("--epochs", help="yaml file with epochs listed. "
-                        "default: %s-epochs.yaml" % (distro),
-                        default="%s-epochs.yaml" % distro)
+    parser.add_argument("--epochs", help="yaml file with epochs listed.")
     parser.add_argument("input-template", nargs='?',
                         help="specfile jinja2 template to render. "
                         "default: *.spec.j2")
@@ -242,8 +254,12 @@ def main():
             return 2
         output_fn, _, _ = input_template.rpartition('.')
 
-    epochs = _get_epochs(args['epochs'])
-    requirements = _get_requirements(args['requirements'])
+    try:
+        epochs = _get_epochs(args['epochs'])
+        requirements = _get_requirements(args['requirements'])
+    except IOError as e:
+        print(e)
+        return 3
     spec = generate_spec(args['spec_style'], epochs, requirements,
                          input_template)
     if output_fn and output_fn != '-':
